@@ -4,16 +4,16 @@
 """Some checks on files or directories."""
 import os
 import re
-from typing import List
-from user_tools import util_cmd
+from typing import Union
+from pathlib import Path
 
 
-def is_exist(file_path: str, create: bool = False) -> bool:
+def is_exist(file_path: Union[str, Path], create: bool = False) -> bool:
     """Test whether file_path exists.
 
     :param file_path(str): The path that needs to be judged.\n
-    :param create(bool): Whether to create.
-        If create is True, create a directory named file_path if it does not exist.
+    :param create(bool): Whether to create. If create is True,\n
+            create a directory named file_path if it does not exist.\n
     :return(bool): A boolean representing whether file_path exists."""
 
     if create and not os.path.exists(file_path):
@@ -21,13 +21,13 @@ def is_exist(file_path: str, create: bool = False) -> bool:
     return os.path.exists(file_path)
 
 
-def is_not_null(file_path: str) -> bool:
+def is_not_null(file_path: Union[str, Path]) -> bool:
     """Test whether file_path is not null.
 
     :param file_path(str): The path that needs to be judged.\n
-    :return(bool): Returns whether file_path is not null.
-        Return True if file_path exist and not null.
-        Return False, it may be the following:
+    :return(bool): Returns whether file_path is not null.\n
+        Return True if file_path exist and not null.\n
+        Return False, it may be the following:\n
             file_path not file or dir; file_path not exist."""
 
     result = False
@@ -39,15 +39,15 @@ def is_not_null(file_path: str) -> bool:
     return result
 
 
-def file_or_dir(file_path: str) -> str:
+def file_or_dir(file_path: Union[str, Path]) -> str:
     """ Returns file type of the file_path.
 
     :param file_path(str): The path that needs to be judged.\n
-    :return(str): Returns file type of the file_path.
-        The return values are as follows.
-            "dir": If file_path is a directory,
-            "file": If file_path is a file,
-            file_path + "Not exist!": If file_path is not exist
+    :return(str): Returns file type of the file_path.\n
+        The return values are as follows.\n
+            "dir": If file_path is a directory,\n
+            "file": If file_path is a file,\n
+            file_path + "Not exist!": If file_path is not exist\n
             "Not file or dir!": If file_path not a dir or file."""
 
     result = ""
@@ -63,12 +63,13 @@ def file_or_dir(file_path: str) -> str:
 
 
 def check_ip(ip: str) -> bool:
-    """Test whether the IP is valid
-    :param ip(str): The IP that needs to be judged.
-    :return(bool): Returns whether url is valid.
+    """Test whether the IP is valid.
+
+    :param ip(str): The IP that needs to be judged.\n
+    :return(bool): Returns whether url is valid.\n
         Return False, if the IP is not legal."""
 
-    ip_rex = '^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$'
+    ip_rex = r'(?=(\b|\D))(((\d{1,2})|(1\d{1,2})|(2[0-4]\d)|(25[0-5]))\.){3}((\d{1,2})|(1\d{1,2})|(2[0-4]\d)|(25[0-5]))(?=(\b|\D))'
 
     is_legal = re.match(re.compile(ip_rex), ip)
     if is_legal:
@@ -80,11 +81,8 @@ def check_ip(ip: str) -> bool:
 def check_url(url: str, style: str = "http") -> bool:
     """Test whether url is valid.
 
-    this way is not finished
-    ==
-
     :params url(str): The url that needs to be judged.\n
-    :return(bool): Returns whether url is valid.
+    :return(bool): Returns whether url is valid.\n
         Return False, if the style is not web or git.
     """
 
@@ -92,15 +90,7 @@ def check_url(url: str, style: str = "http") -> bool:
     if style == "http":
         result = True if re.match(r'^https?:/{2}\w.+$', url) else False
     elif style == "git":
-        pass
+        result = True if re.match(
+            r'^(http(s)?:\/\/([^\/]+?\/){2}|git@[^:]+:[^\/]+?\/).*?.git$', url
+        ) else False
     return result
-
-
-def check_process(name: str) -> List[str]:
-    name = name.lower()
-    out = util_cmd.get_out_text("tasklist")["output_text"].lower()
-    process_list = []
-    for i in out.split("\r\n"):
-        if name in i:
-            process_list.append(i)
-    return process_list
