@@ -7,11 +7,11 @@ import platform
 from typing import Any, Dict, List
 
 
-def get_out_text(cmd: List[str], encoding: str = "UTF-8") -> Dict[str, Any]:
+def get_out_text(cmd: List[str], encoding: str = "") -> Dict[str, Any]:
     """Run command with arguments and return its output.
 
-    :param cmd(list): Command to be executed.
-        The command format is ["command", ["arg", "arg1",...]]
+    :param cmd(list): Command to be executed.\n
+        The command format is ["command", ["arg", "arg1",...]]\n
     :return(dict): Command execution results of cmd."""
     if not encoding:
         if "win" in platform.system().lower():
