@@ -3,6 +3,8 @@
 
 """Some functions related to hash operations."""
 import hashlib
+from pathlib import Path
+from typing import Union
 from user_tools import util_check
 
 
@@ -10,7 +12,7 @@ def get_str_md5(string: str) -> str:
     """Returns the MD5 value of a string.
 
     :param string(str): String to get the MD5 value.\n
-    :return(str): The MD5 value of string.
+    :return(str): The MD5 value of string.\n
         If string is empty, the MD5 value is empty."""
 
     md5name = ""
@@ -20,12 +22,12 @@ def get_str_md5(string: str) -> str:
     return md5name
 
 
-def get_file_md5(file_path: str) -> str:
+def get_file_md5(file_path: Union[str, Path]) -> str:
     """Returns the MD5 value of a file.
 
     :param file_path(str): File path to get MD5 value.\n
-    :return(str): the MD5 value of file_path.
-        If the MD5 value is empty, it may be the following:
+    :return(str): the MD5 value of file_path.\n
+        If the MD5 value is empty, it may be the following:\n
             file_path not file; file_path not exist; file_path is null."""
 
     md5name = ""
