@@ -3,16 +3,17 @@
 
 """Some functions related to json file operations."""
 import json
-from typing import Any, Dict
+from typing import Any, Dict, Union
+from pathlib import Path
 from user_tools import util_check
 
 
-def read_json(json_file: str) -> Dict[Any, Any]:
+def read_json(json_file: Union[str, Path]) -> Dict[Any, Any]:
     """Return the contents of json_file.
 
     :param json_file(str): Json file to be read.\n
-    :return(dict): the contents of json_file.
-        If the return value is empty, it may be the following:
+    :return(dict): the contents of json_file.\n
+        If the return value is empty, it may be the following:\n
             json_file not file; json_file not exist; json_file is null."""
 
     json_dict = {}
@@ -24,23 +25,23 @@ def read_json(json_file: str) -> Dict[Any, Any]:
     return json_dict
 
 
-def write_json(json_file: str, json_dict: Dict[Any, Any], mode: str = "w") -> None:
+def write_json(json_file: Union[str, Path], json_dict: Dict[Any, Any],
+               mode: str = "w") -> None:
     """Write the contents of json_dict to json_file.
 
     :param json_file(str): Json file to be written.\n
     :param json_dict(str): What will be written to the json file.\n
-    :param mode(str): How to write json file, default is "w".
-        Character Meaning
-        -----------------------------------
+    :param mode(str): How to write json file, default is "w".\n
+        Character Meaning\n
             'w'   open for writing, create if not exists.
-                  truncating the file first.
-            'x'   create a new file and open it for writing
+                  truncating the file first.\n
+            'x'   create a new file and open it for writing.\n
             'a'   open for writing, create if not exists.
-                  appending to the end of the file.
+                  appending to the end of the file.\n
             'b'   binary mode.
-                  If you use this, no encoding parameter is required
-            't'   text mode (default)
-            '+'   open a disk file for updating (reading and writing)
+                  If you use this, no encoding parameter is required\n
+            't'   text mode (default)\n
+            '+'   open a disk file for updating (reading and writing)\n
     :return(None): No return value."""
 
     with open(json_file, mode, encoding="UTF-8") as f:
