@@ -5,8 +5,8 @@
 import random
 
 
-def random_str(str):
+def random_str(string: str) -> str:
     """Randomly shuffle strings."""
-    list_str = list(str)
+    list_str = list(string)
     random.shuffle(list_str)
-    return list_str
+    return "".join(list_str)
